@@ -71,24 +71,30 @@ indicator_display (gpointer indicator, guint timestamp, const gchar *channel)
 		current_ctx = xchat_get_context(ph);
 		xchat_context *ctx;
 		ctx = xchat_find_context (ph, NULL, channel);
-                g_debug ("INDICATOR: Changing to channel %s", channel);
+                /*
+		g_debug ("INDICATOR: Changing to channel %s", channel);
+		*/
 		win = (GtkWindow *)xchat_get_info (ph, "win_ptr");
 		if (xchat_set_context (ph, ctx)) {
-			g_debug ("INDICATOR: Showing window");
+			/*
+			g_debug ("xchat-indicator: Showing window");
+			*/
 			xchat_command (ph, "GUI SHOW"); 
 			xchat_command (ph, "GUI FOCUS"); 
 			gtk_widget_show (GTK_WIDGET (win));
 			really_activate_window (GTK_WINDOW (win));
 			/* gtk_window_present_with_time(GTK_WINDOW (win), timestamp); */
 		} else {
-			g_debug ("INDICATOR: context change fail");
+			g_warning ("xchat-indicator: context change fail");
 		}
 		if (indicator != NULL) {
 			remove_indicator (channel, indicator);
 		}
 		xchat_set_context (ph, current_ctx);
 	}
-	g_debug ("INDICATOR: Indicator displayed");
+	/*
+	g_debug ("xchat-indicator: Indicator displayed");
+	*/
 }
 
 static void
@@ -98,14 +104,18 @@ server_display (IndicateServer * indicate_server, guint timestamp, gpointer data
         really_activate_window (GTK_WINDOW (win));
 	xchat_command (ph, "GUI SHOW"); 
 	/* gtk_window_present_with_time(GTK_WINDOW (win), timestamp); */
-	g_debug ("INDICATOR: Showing the window");
+	/*
+	g_debug ("xchat-indicator: Showing the window");
+	*/
         /* XXX: Should clear all indicators */
 }
 
 static void 
 hide_indicator (const gchar *channel, gpointer indicator, gpointer data)
 {
-	g_debug ("INDICATOR: hiding indicator");
+	/*
+	g_debug ("xchat-indicator: hiding indicator");
+	*/
 	indicate_indicator_hide (INDICATE_INDICATOR (indicator));
 }
 
@@ -114,7 +124,9 @@ remove_indicator (const gchar *channel, gpointer indicator)
 {
 	if (indicator == g_hash_table_lookup (indicators, channel))
 	{
-		g_debug ("INDICATOR: removing indicator for channel %s", channel);
+		/*
+		g_debug ("xchat-indicator: removing indicator for channel %s", channel);
+		*/
 		indicate_indicator_hide (INDICATE_INDICATOR (indicator));
 		g_hash_table_remove (indicators, channel);
 		g_object_unref (indicator);
@@ -126,15 +138,21 @@ remove_indicator (const gchar *channel, gpointer indicator)
         }
 
 	gint count = g_hash_table_size (indicators);
+	/*
 	g_debug ("LAUNCHER: count is %d", count);
+	*/
 	if (count > 0)
 	{
+		/*
 		g_debug ("LAUNCHER: setting count to %d", count);
+		*/
 		unity_launcher_entry_set_count (launcher, count);
 		unity_launcher_entry_set_count_visible (launcher, TRUE);
 	} else {
 		unity_launcher_entry_set_count (launcher, count);
+		/*
 		g_debug ("LAUNCHER: hiding count");
+		*/
 		unity_launcher_entry_set_count_visible (launcher, FALSE);
 	}
 #endif
@@ -146,7 +164,9 @@ update_indicator (gpointer indicator)
 	GTimeVal time;
 	if (indicator != NULL)
 	{
-		g_debug ("INDICATOR: found existing indicator");
+		/*
+		g_debug ("xchat-indicator: found existing indicator");
+		*/
 		g_get_current_time (&time);
 		indicate_indicator_set_property_time (INDICATE_INDICATOR (indicator),
 			"time", &time);
@@ -203,7 +223,9 @@ add_indicator (const gchar *channel)
 	}
 
 	gint count = g_hash_table_size (indicators);
+	/*
 	g_debug ("LAUNCHER: count is %d", count);
+	*/
 	if (count > 0)
 	{
 		unity_launcher_entry_set_count (launcher, count);
@@ -222,10 +244,10 @@ nick_change_cb (char *word[], void *data)
         xchat_set_context (ph, ctx);
         const gchar *channel = xchat_get_info (ph, "channel");
 
-        g_debug ("INDICATOR: Checking for indicators for %s", channel);
+        g_debug ("xchat-indicator: Checking for indicators for %s", channel);
         indicator = g_hash_table_lookup (indicators, channel);
         if (indicator != NULL) {
-                g_debug ("INDICATOR: Found indicator for %s, changing it to %s", word[1], word[2]);
+                g_debug ("xchat-indicator: Found indicator for %s, changing it to %s", word[1], word[2]);
                 indicate_indicator_set_property (INDICATE_INDICATOR (indicator),
                         "sender", channel);
         }
@@ -245,7 +267,9 @@ indicate_msg_cb (char *word[], gpointer data)
 	if (focused == channel && GTK_WINDOW (win)->has_toplevel_focus)
 		return XCHAT_EAT_NONE;
 
-	g_debug ("INDICATOR: channel %s is not focused, adding indicator", channel);
+	/*
+	g_debug ("xchat-indicator: channel %s is not focused, adding indicator", channel);
+	*/
 	add_indicator (channel);
 	return XCHAT_EAT_NONE;
 }
@@ -256,10 +280,14 @@ focus_tab_cb (char *word[], gpointer data)
 	gpointer indicator;
 	const gchar *channel;
 	channel = xchat_get_info (ph, "channel");
-	g_debug ("INDICATOR: tab focused for channel %s", channel);
+	/*
+	g_debug ("xchat-indicator: tab focused for channel %s", channel);
+	*/
         indicator = g_hash_table_lookup(indicators, channel);
 	if (indicator != NULL) {
-		g_debug ("INDICATOR: found indicator for %s", channel);
+		/*
+		g_debug ("xchat-indicator: found indicator for %s", channel);
+		*/
 		remove_indicator (channel, indicator);
         }
 	focused = channel;
@@ -273,14 +301,20 @@ focus_win_cb (GtkWindow *win,  GParamSpec *pspec, gpointer data)
 	{
 		return FALSE;
 	}
-	g_debug ("INDICATOR: window focused");
+	/*
+	g_debug ("xchat-indicator: window focused");
+	*/
         gpointer indicator;
         const gchar *channel;
         channel = xchat_get_info (ph, "channel");
-        g_debug ("INDICATOR: tab focused for channel %s", channel);
+	/*
+        g_debug ("xchat-indicator: tab focused for channel %s", channel);
+	*/
         indicator = g_hash_table_lookup(indicators, channel);
         if (indicator != NULL) {
-                g_debug ("INDICATOR: found indicator for %s", channel);
+		/*
+                g_debug ("xchat-indicator: found indicator for %s", channel);
+		*/
                 remove_indicator (channel, indicator);
         }
         focused = channel;
@@ -391,7 +425,9 @@ xchat_plugin_deinit (void)
 
 	g_hash_table_iter_init (&iter, indicators);
 	while (g_hash_table_iter_next (&iter, &channel, &indicator)) {
-		g_debug ("INDICATOR: removing indicator for channel %p", channel);
+		/*
+		g_debug ("xchat-indicator: removing indicator for channel %p", channel);
+		*/
 		indicate_indicator_hide (INDICATE_INDICATOR (indicator));
 	}
 
@@ -399,7 +435,7 @@ xchat_plugin_deinit (void)
 	/* Kill the hash table */
 	g_hash_table_destroy(indicators);
 
-	g_debug ("INDICATOR: Hiding the indicator server");
+	g_print ("xchat-indicator: Hiding the indicator server");
 
 	indicate_server_hide (indicate_server);
 
